use serde::Deserialize;

use crate::proxy::Mirror;

/// Mirrord configuration
#[derive(Debug, Deserialize, Clone)]
pub struct Config {
    /// List of mirror hosts to fetch data from.
    pub mirrors: Vec<String>,
    /// Directory path where cached data will be stored.
    pub cache_dir: String,
    /// Regex for which paths should never use cache
    pub no_cache: String,
    /// Time-to-live (TTL) duration for cached data in minutes
    pub ttl: Option<usize>,
    /// Regex for allowing only specific path requests
    pub only_allow: Option<String>,
    /// Index Page
    pub index: Option<String>,
}

impl Config {
    pub fn to_proxy(&self) -> Mirror {
        Mirror::new(self)
    }
}
